@@ -4,7 +4,6 @@ extern crate prettytable;
 use colored::*;
 use ctrlc;
 
-#[cfg(any(target_os = "windows", target_os = "macos"))]
 use league_client_connector::LeagueClientConnector;
 
 use prettytable::{format, Table};
@@ -147,9 +146,9 @@ fn main() {
     };
 
     #[cfg(all(not(target_os = "windows"), not(target_os = "macos")))]
-    let client_lockfile = None;
+    let client_lockfile: Option<league_client_connector::RiotLockFile> = None;
 
-    let mut clientapi = None;
+    let mut clientapi: Option<client_api::ClientAPI> = None;
 
     #[cfg(all(debug_assertions, any(target_os = "windows", target_os = "macos")))]
     if !client_lockfile.as_ref().is_none() {
@@ -161,6 +160,11 @@ fn main() {
         clientapi = Some(client_api::ClientAPI::new(lockfile));
     }
 
+    #[cfg(any(target_os = "windows", target_os = "macos"))]
+    if !client_lockfile.as_ref().is_none() {
+        clientapi = Some(client_api::ClientAPI::new(client_lockfile.clone().unwrap()));
+    }
+
     let mut client_summoner: Option<Box<ClientSummoner>> = None;
     match clientapi {
         Some(ref api) => {
